@@ -191,15 +191,15 @@ class Reference(Base):
     node_type = "primary"
     node_name = "Reference"
     slug = "reference"
-    required = ["group", "title", "doi"]
-    unique_together = ["doi"]
+    required = ["group", "title"]
+    unique_together = ["title", "created_by"]
 
     @beartype
     def __init__(
         self,
         group: Union[Group, str] = None,
         title: str = None,
-        doi: str = None,
+        doi: Union[str, None] = None,
         authors: Union[list[str], None] = None,
         journal: Union[str, None] = None,
         publisher: Union[str, None] = None,
@@ -798,13 +798,13 @@ class Component(Base):
     node_type = "secondary"
     node_name = "Component"
     list_name = "components"
-    required = ["component"]
+    required = ["material"]
 
     @beartype
-    def __init__(self, component_uid: int = 1, component: Union[Base, str] = None):
+    def __init__(self, component_id: int = 1, material: Union[Base, str] = None):
         super().__init__()
-        self.component_uid = component_uid
-        self.component = component
+        self.component_id = component_id
+        self.material = material
         validate_required(self)
 
 
@@ -909,7 +909,7 @@ class Inventory(Base):
         self.collection = collection
         self.name = name
         self.description = description
-        self.materials = materials
+        self.materials = materials if materials else []
         self.public = public
         self.created_at = None
         self.updated_at = None
@@ -933,17 +933,17 @@ class Ingredient(Base):
     node_type = "secondary"
     node_name = "Ingredient"
     list_name = "ingredients"
-    required = ["ingredient"]
+    required = ["material"]
 
     @beartype
     def __init__(
         self,
-        ingredient: Union[Material, str],
+        material: Union[Material, str],
         keyword: str = None,
         quantities: list[Union[Quantity, dict]] = None,
     ):
         super().__init__()
-        self.ingredient = ingredient
+        self.material = material
         self.keyword = keyword
         self.quantities = quantities if quantities else []
         validate_required(self)
